Design Files Interaction
========================

In this project, it is assumed design and path variables are inputted
from the user as strings, rather than ``pathlib`` components to maintain
universality of use for most Python users.
